@@ -319,7 +319,7 @@ public class operation : object {
 		}
 		
 		this.phrase = this.phrase.Replace("X", "x");
-		this.phrase = this.phrase.Replace(".", ",");
+		this.phrase = this.phrase.Replace(".", ".");
 		
 		this.phrase = this.phrase.Replace("(-", "(0-");
 		
